==> django-security-logger-0.3.29.tar.gz: django-security-logger-0.3.29/security/management/__init__.py <==
import sys

from argparse import ArgumentParser

import django
from django.core.management import call_command as call_command_original
from django.core.management import execute_from_command_line as execute_from_command_line_original
from django.core.management import handle_default_options


def execute_from_command_line(argv=None):

    def execute_from_command_line_with_stdout(argv=None, stdout=None, stderr=None):
        try:
            if stdout:
                sys.stdout = stdout
            if stderr:
                sys.stderr = stderr
            execute_from_command_line_original(argv=argv)
        finally:
            if stdout:
                sys.stdout = sys.__stdout__
            if stderr:
                sys.stderr = sys.__stderr__

    if len(argv) > 1:
        # some arguments must be processed before django setup
        parser = ArgumentParser()
        parser.add_argument('--settings')
        parser.add_argument('--pythonpath')
        options, args = parser.parse_known_args(argv[2:])
        handle_default_options(options)

        django.setup()

        from security.utils import CommandLogger
        return CommandLogger(
            command_function=execute_from_command_line_with_stdout,
            command_kwargs={'argv': argv},
            name=argv[1],
            input=' '.join(argv[2:]),
            executed_from_command_line=True
        ).run()
    else:
        execute_from_command_line_original(argv=argv)


def call_command(command_name, stdout=None, stderr=None, *args, **options):
    stdout = sys.stdout if stdout is None else stdout
    stderr = sys.stderr if stderr is None else stderr

    from security.utils import CommandLogger
    return CommandLogger(
        command_function=call_command_original,
        command_args=(command_name,) + tuple(args),
        command_kwargs=options,
        stdout=stdout,
        stderr=stderr,
        name=command_name,
        input=', '.join(
            list(args)+['{}={}'.format(k, v) for k, v in options.items()]
        )
    ).run()

==> django-security-logger-0.3.40.tar.gz: django-security-logger-0.3.40/security/management/__init__.py <==
import sys

from argparse import ArgumentParser

import django
from django.core.management import call_command as call_command_original
from django.core.management import execute_from_command_line as execute_from_command_line_original
from django.core.management import handle_default_options, CommandError, CommandParser


def execute_from_command_line(argv=None):

    def execute_from_command_line_with_stdout(argv=None, stdout=None, stderr=None):
        try:
            if stdout:
                sys.stdout = stdout
            if stderr:
                sys.stderr = stderr
            execute_from_command_line_original(argv=argv)
        finally:
            if stdout:
                sys.stdout = sys.__stdout__
            if stderr:
                sys.stderr = sys.__stderr__

    if len(argv) > 1:
        from security.utils import CommandLogger

        # some arguments must be processed before django setup
        parser = CommandParser(None, usage="%(prog)s subcommand [options] [args]", add_help=False)
        parser.add_argument('--settings')
        parser.add_argument('--pythonpath')
        parser.add_argument('args', nargs='*')  # catch-all
        try:
            options, args = parser.parse_known_args(argv[2:])
            handle_default_options(options)
        except CommandError:
            pass  # Ignore any option errors at this point.

        django.setup()

        return CommandLogger(
            command_function=execute_from_command_line_with_stdout,
            command_kwargs={'argv': argv},
            name=argv[1],
            input=' '.join(argv[2:]),
            executed_from_command_line=True
        ).run()

    else:
        execute_from_command_line_original(argv=argv)


def call_command(command_name, stdout=None, stderr=None, *args, **options):
    stdout = sys.stdout if stdout is None else stdout
    stderr = sys.stderr if stderr is None else stderr

    from security.utils import CommandLogger
    return CommandLogger(
        command_function=call_command_original,
        command_args=(command_name,) + tuple(args),
        command_kwargs=options,
        stdout=stdout,
        stderr=stderr,
        name=command_name,
        input=', '.join(
            list(args)+['{}={}'.format(k, v) for k, v in options.items()]
        )
    ).run()
